==> haskell-cmdargs-0.10.14-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmdargs
version: 0.10.14
id: cmdargs-0.10.14-CJAOGiZkh3OIu1n8WPqRj9
key: cmdargs-0.10.14-CJAOGiZkh3OIu1n8WPqRj9
license: BSD3
copyright: Neil Mitchell 2009-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/cmdargs#readme
synopsis: Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.
    .
    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.
    .
    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.
    .
    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.
    .
    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Implicit
    System.Console.CmdArgs.Text System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Verbosity System.Console.CmdArgs.Quote
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.ExpandArgsAt
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
abi: d95443035925233cf05f550e82bf3b8c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cmdargs-0.10.14
library-dirs: /usr/lib/ghc-8.0.1/site-local/cmdargs-0.10.14
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cmdargs-0.10.14
hs-libraries: HScmdargs-0.10.14-CJAOGiZkh3OIu1n8WPqRj9
depends:
    base-4.9.0.0 filepath-1.4.1.0 process-1.4.2.0
    template-haskell-2.11.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html: /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmdargs-0.10.15-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmdargs
version: 0.10.15
id: cmdargs-0.10.15-BgqoY5S3enuCldigbbRRIV
key: cmdargs-0.10.15-BgqoY5S3enuCldigbbRRIV
license: BSD3
copyright: Neil Mitchell 2009-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/cmdargs#readme
synopsis: Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.
    .
    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.
    .
    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.
    .
    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.
    .
    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Implicit
    System.Console.CmdArgs.Text System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Verbosity System.Console.CmdArgs.Quote
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.ExpandArgsAt
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
abi: fc824782527f46ff3ef1afedfdc9e48a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cmdargs-0.10.15
library-dirs: /usr/lib/ghc-8.0.1/site-local/cmdargs-0.10.15
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cmdargs-0.10.15
hs-libraries: HScmdargs-0.10.15-BgqoY5S3enuCldigbbRRIV
depends:
    base-4.9.0.0 filepath-1.4.1.0 process-1.4.2.0
    template-haskell-2.11.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html: /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
